wagoe.events.shell.module-wiring

Integrant wiring for the event bus.

The layer that emits a key registers it (BOU-131), so an application that configures :wagoe/events requires this namespace and nothing in the framework needs to know the module exists.

Integrant wiring for the event bus.

The layer that emits a key registers it (BOU-131), so an application that
configures `:wagoe/events` requires this namespace and nothing in the
framework needs to know the module exists.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries