Integrant wiring for the event bus.
The layer that emits a key registers it (BOU-131), so an application that
configures :wagoe/events requires this namespace and nothing in the
framework needs to know the module exists.
Integrant wiring for the event bus. The layer that emits a key registers it (BOU-131), so an application that configures `:wagoe/events` requires this namespace and nothing in the framework needs to know the module exists.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |